@@ -1,7 +1,7 @@
 package Org::To::HTML;
 
-our $DATE = '2018-10-30'; # DATE
-our $VERSION = '0.231'; # VERSION
+our $DATE = '2020-09-11'; # DATE
+our $VERSION = '0.232'; # VERSION
 
 use 5.010001;
 use strict;
@@ -27,6 +27,7 @@ our @EXPORT_OK = qw(org_to_html);
 has naked => (is => 'rw');
 has html_title => (is => 'rw');
 has css_url => (is => 'rw');
+has inline_images => (is =>  'rw');
 
 our %SPEC;
 $SPEC{org_to_html} = {
@@ -98,6 +99,11 @@ _
         ignore_unknown_settings => {
             schema => 'bool',
         },
+        inline_images => {
+            summary => 'If set to true, will make link to an image filename into an <img> element instead of <a>',
+            schema => 'bool',
+            default => 1,
+        },
     },
 };
 sub org_to_html {
@@ -116,11 +122,12 @@ sub org_to_html {
     }
 
     my $obj = ($args{_class} // __PACKAGE__)->new(
-        include_tags => $args{include_tags},
-        exclude_tags => $args{exclude_tags},
-        css_url      => $args{css_url},
-        naked        => $args{naked},
-        html_title   => $args{html_title} // $args{source_file},
+        include_tags  => $args{include_tags},
+        exclude_tags  => $args{exclude_tags},
+        css_url       => $args{css_url},
+        naked         => $args{naked},
+        html_title    => $args{html_title} // $args{source_file},
+        inline_images => $args{inline_images} // 1,
     );
 
     my $html = $obj->export($doc);
@@ -375,24 +382,43 @@ sub export_timestamp {
 }
 
 sub export_link {
+    require Filename::Image;
+
     my ($self, $elem) = @_;
 
     my $html = [];
-    push @$html, "<a href=\"";
-    if ($elem->link =~ m!^\w+:!) {
-        # looks like a url
-        push @$html, $elem->link;
+    my $link = $elem->link;
+    my $looks_like_image = Filename::Image::check_image_filename(filename => $link);
+    my $inline_images = $self->inline_images;
+    if ($inline_images && $looks_like_image) {
+        # TODO: extract to method e.g. settings
+        my $settings;
+        my $s = $elem;
+        while (1) {
+            $s = $s->prev_sibling;
+            last unless $s && $s->isa("Org::Element::Setting");
+            $settings->{ $s->name } = $s->raw_arg;
+        }
+        #use DD; dd $settings;
+        my $caption = $settings->{CAPTION};
+
+        push @$html, "<figure>" if defined $caption;
+        push @$html, "<img src=\"";
+        push @$html, $link;
+        push @$html, "\" />";
+        push @$html, "<figcaption>", encode_entities($caption), "</figcaption>";
+        push @$html, "</figure>" if defined $caption;
     } else {
-        # assume it's an anchor
-        push @$html, "#", __escape_target($elem->link);
+        push @$html, "<a href=\"";
+        push @$html, $link;
+        push @$html, "\">";
+        if ($elem->description) {
+            push @$html, $self->export_elements($elem->description);
+        } else {
+            push @$html, $link;
+        }
+        push @$html, "</a>";
     }
-    push @$html, "\">";
-    if ($elem->description) {
-        push @$html, $self->export_elements($elem->description);
-    } else {
-        push @$html, $elem->link;
-    }
-    push @$html, "</a>";
 
     join "", @$html;
 }
@@ -412,7 +438,7 @@ Org::To::HTML - Export Org document to HTML
 
 =head1 VERSION
 
-This document describes version 0.231 of Org::To::HTML (from Perl distribution Org-To-HTML), released on 2018-10-30.
+This document describes version 0.232 of Org::To::HTML (from Perl distribution Org-To-HTML), released on 2020-09-11.
 
 =head1 SYNOPSIS
 
@@ -501,9 +527,13 @@ Otherwise, trees that do not carry one of these tags will be excluded. If a
 selected tree is a subtree, the heading hierarchy above it will also be selected
 for export, but not the text below those headings.
 
+=item * B<inline_images> => I<bool> (default: 1)
+
+If set to true, will make link to an image filename into an <imgE<gt> element instead of <aE<gt>.
+
 =item * B<naked> => I<bool>
 
-Don't wrap exported HTML with HTML/HEAD/BODY elements.
+Don't wrap exported HTML with HTMLE<sol>HEADE<sol>BODY elements.
 
 =item * B<source_file> => I<str>
 
@@ -519,6 +549,7 @@ HTML file to write to.
 
 If not specified, HTML string will be returned.
 
+
 =back
 
 Returns an enveloped result (an array).
@@ -582,7 +613,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
